// ▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓
//
// PREP EXAMPLE YAML
//
// <#Author = Robert Mollentze>
// <#Email = robmllze@gmail.com>
// <#Date = 8/27/2021>
//
// See LICENSE file
//
// ▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓▓

library prep;

import 'dart:io' show File;

// ░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░

/// A prep.yaml template.
const PREP_EXAMPLE_YAML = //
    '# This file was auto-generated by prep().\n'
    '# Rename it to "prep.yaml" to use it.\n'
    '# If you like this package, please follow me on Instagram @robmllze.\n'
    '# Feel free to DM me about bugs or questions.\n'
    '\n'
    '# Files in this directory and all its subdirectories will be parsable.\n'
    'path: "."\n'
    '\n'
    '# If you need to tweak the syntax, do it here.\n'
    '# Note: This is experimental!\n'
    'syntax_beg: "<" # This also works well: "`"\n'
    'syntax_end: ">" # This also works well: "`"\n'
    'syntax_sep: "=" # This also works well: ":"\n'
    '\n'
    '# Set to true to include your environment variables.\n'
    '# Note: This significantly slows down the prep function but it does\n'
    '# not matter if you use it asynchronously.\n'
    'include_env: true\n'
    '\n'
    '# Specify which custom fields to update.\n'
    'update_these_fields: {\n'
    '  "Version": "0.1.0",\n'
    '  "Author": "Robert Mollentze",\n'
    '  "GitHub": "@robmllze",\n'
    '  "Instagram": "@robmllze",\n'
    '  "Email": "robmllze@gmail.com",\n'
    '}\n'
    '\n'
    '# Specify which file types to parse.\n'
    'parse_these_file_types: [\n'
    '  "dart",\n'
    '  "md",\n'
    ']\n'
    '\n'
    '# Specify which files not to parse.\n'
    'dont_parse_these_files: [\n'
    '  "prep.yaml",\n'
    ']\n';

/// An empty prep.yaml template.
const PREP_EXAMPLE_YAML_EMPTY = //
    '# This file was auto-generated by prep().\n'
    '# Rename it to "prep.yaml" to use it.\n'
    '# If you like this package, please follow me on Instagram @robmllze.\n'
    '# Feel free to DM me about bugs or questions.\n'
    '\n'
    '# Files in this directory and all its subdirectories will be parsable.\n'
    'path: "."\n'
    '\n'
    '# If you need to tweak the syntax, do it here.\n'
    '# Note: This is experimental!\n'
    'syntax_beg: "<" # This also works well: "`"\n'
    'syntax_end: ">" # This also works well: "`"\n'
    'syntax_sep: "=" # This also works well: ":"\n'
    '\n'
    '# Set to true to include your environment variables.\n'
    '# Note: This significantly slows down the prep function but it does\n'
    '# not matter if you use it asynchronously.\n'
    'include_env: true\n'
    '\n'
    '# Specify which custom fields to update.\n'
    'update_these_fields: {\n'
    '}\n'
    '\n'
    '# Specify which file types to parse.\n'
    'parse_these_file_types: [\n'
    '  "dart",\n'
    ']\n'
    '\n'
    '# Specify which files not to parse.\n'
    'dont_parse_these_files: [\n'
    ']\n';

// ░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░

/// Generates a prep.yaml example in the project directory called
/// prep_example.yaml.
Future<void> genPrepExampleYaml() {
  return Future<void>(
    () async {
      final _file0 = File("./prep.yaml");
      final _file1 = File("./prep_example.yaml");
      // Only generate file if both files above doesn't exist.
      if (!await _file0.exists() && !await _file1.exists()) {
        await _file1.writeAsString(PREP_EXAMPLE_YAML);
      }
    },
  );
}

/// Generates a prep.yaml example in the current directory called
/// `name`.
Future<void> genPrepExampleYamlEmpty(final String name) {
  return Future<void>(
    () async {
      await File(name).writeAsString(PREP_EXAMPLE_YAML_EMPTY);
    },
  );
}
